@@ -21,7 +21,9 @@ import warnings
 
 import jsonpatch
 
+from openstack.baremetal.v1._proxy import Proxy
 from openstack.cloud import exc
+from openstack import warnings as os_warnings
 
 
 def _normalize_port_list(nics):
@@ -38,12 +40,14 @@ def _normalize_port_list(nics):
             except KeyError:
                 raise TypeError(
                     "Either 'address' or 'mac' must be provided "
-                    "for port %s" % row)
+                    "for port %s" % row
+                )
         ports.append(dict(row, address=address))
     return ports
 
 
 class BaremetalCloudMixin:
+    baremetal: Proxy
 
     def list_nics(self):
         """Return a list of all bare metal ports."""
@@ -134,32 +138,34 @@ class BaremetalCloudMixin:
                 raise exc.OpenStackCloudException(
                     "Refusing to inspect available machine %(node)s "
                     "which is associated with an instance "
-                    "(instance_uuid %(inst)s)" %
-                    {'node': node.id, 'inst': node.instance_id})
+                    "(instance_uuid %(inst)s)"
+                    % {'node': node.id, 'inst': node.instance_id}
+                )
 
             return_to_available = True
             # NOTE(TheJulia): Changing available machine to managedable state
             # and due to state transitions we need to until that transition has
             # completed.
-            node = self.baremetal.set_node_provision_state(node, 'manage',
-                                                           wait=True,
-                                                           timeout=timeout)
+            node = self.baremetal.set_node_provision_state(
+                node, 'manage', wait=True, timeout=timeout
+            )
 
         if node.provision_state not in ('manageable', 'inspect failed'):
             raise exc.OpenStackCloudException(
                 "Machine %(node)s must be in 'manageable', 'inspect failed' "
                 "or 'available' provision state to start inspection, the "
-                "current state is %(state)s" %
-                {'node': node.id, 'state': node.provision_state})
+                "current state is %(state)s"
+                % {'node': node.id, 'state': node.provision_state}
+            )
 
-        node = self.baremetal.set_node_provision_state(node, 'inspect',
-                                                       wait=True,
-                                                       timeout=timeout)
+        node = self.baremetal.set_node_provision_state(
+            node, 'inspect', wait=True, timeout=timeout
+        )
 
         if return_to_available:
-            node = self.baremetal.set_node_provision_state(node, 'provide',
-                                                           wait=True,
-                                                           timeout=timeout)
+            node = self.baremetal.set_node_provision_state(
+                node, 'provide', wait=True, timeout=timeout
+            )
 
         return node
 
@@ -168,19 +174,27 @@ class BaremetalCloudMixin:
         try:
             yield
         except Exception as exc:
-            self.log.debug("cleaning up node %s because of an error: %s",
-                           node.id, exc)
+            self.log.debug(
+                "cleaning up node %s because of an error: %s", node.id, exc
+            )
             tb = sys.exc_info()[2]
             try:
                 self.baremetal.delete_node(node)
             except Exception:
-                self.log.debug("could not remove node %s", node.id,
-                               exc_info=True)
+                self.log.debug(
+                    "could not remove node %s", node.id, exc_info=True
+                )
             raise exc.with_traceback(tb)
 
-    def register_machine(self, nics, wait=False, timeout=3600,
-                         lock_timeout=600, provision_state='available',
-                         **kwargs):
+    def register_machine(
+        self,
+        nics,
+        wait=False,
+        timeout=3600,
+        lock_timeout=600,
+        provision_state='available',
+        **kwargs
+    ):
         """Register Baremetal with Ironic
 
         Allows for the registration of Baremetal nodes with Ironic
@@ -231,9 +245,10 @@ class BaremetalCloudMixin:
         :returns: Current state of the node.
         """
         if provision_state not in ('enroll', 'manageable', 'available'):
-            raise ValueError('Initial provision state must be enroll, '
-                             'manageable or available, got %s'
-                             % provision_state)
+            raise ValueError(
+                'Initial provision state must be enroll, '
+                'manageable or available, got %s' % provision_state
+            )
 
         # Available is tricky: it cannot be directly requested on newer API
         # versions, we need to go through cleaning. But we cannot go through
@@ -244,19 +259,24 @@ class BaremetalCloudMixin:
 
         with self._delete_node_on_error(machine):
             # Making a node at least manageable
-            if (machine.provision_state == 'enroll'
-                    and provision_state != 'enroll'):
+            if (
+                machine.provision_state == 'enroll'
+                and provision_state != 'enroll'
+            ):
                 machine = self.baremetal.set_node_provision_state(
-                    machine, 'manage', wait=True, timeout=timeout)
+                    machine, 'manage', wait=True, timeout=timeout
+                )
                 machine = self.baremetal.wait_for_node_reservation(
-                    machine, timeout=lock_timeout)
+                    machine, timeout=lock_timeout
+                )
 
             # Create NICs before trying to run cleaning
             created_nics = []
             try:
                 for port in _normalize_port_list(nics):
-                    nic = self.baremetal.create_port(node_id=machine.id,
-                                                     **port)
+                    nic = self.baremetal.create_port(
+                        node_id=machine.id, **port
+                    )
                     created_nics.append(nic.id)
 
             except Exception:
@@ -267,10 +287,13 @@ class BaremetalCloudMixin:
                         pass
                 raise
 
-            if (machine.provision_state != 'available'
-                    and provision_state == 'available'):
+            if (
+                machine.provision_state != 'available'
+                and provision_state == 'available'
+            ):
                 machine = self.baremetal.set_node_provision_state(
-                    machine, 'provide', wait=wait, timeout=timeout)
+                    machine, 'provide', wait=wait, timeout=timeout
+                )
 
             return machine
 
@@ -293,15 +316,18 @@ class BaremetalCloudMixin:
         :raises: OpenStackCloudException on operation failure.
         """
         if wait is not None:
-            warnings.warn("wait argument is deprecated and has no effect",
-                          DeprecationWarning)
+            warnings.warn(
+                "wait argument is deprecated and has no effect",
+                os_warnings.OpenStackDeprecationWarning,
+            )
 
         machine = self.get_machine(uuid)
         invalid_states = ['active', 'cleaning', 'clean wait', 'clean failed']
         if machine['provision_state'] in invalid_states:
             raise exc.OpenStackCloudException(
                 "Error unregistering node '%s' due to current provision "
-                "state '%s'" % (uuid, machine['provision_state']))
+                "state '%s'" % (uuid, machine['provision_state'])
+            )
 
         # NOTE(TheJulia) There is a high possibility of a lock being present
         # if the machine was just moved through the state machine. This was
@@ -312,7 +338,8 @@ class BaremetalCloudMixin:
         except exc.OpenStackCloudException as e:
             raise exc.OpenStackCloudException(
                 "Error unregistering node '%s': Exception occured while"
-                " waiting to be able to proceed: %s" % (machine['uuid'], e))
+                " waiting to be able to proceed: %s" % (machine['uuid'], e)
+            )
 
         for nic in _normalize_port_list(nics):
             try:
@@ -379,32 +406,28 @@ class BaremetalCloudMixin:
         machine = self.get_machine(name_or_id)
         if not machine:
             raise exc.OpenStackCloudException(
-                "Machine update failed to find Machine: %s. " % name_or_id)
+                "Machine update failed to find Machine: %s. " % name_or_id
+            )
 
         new_config = dict(machine._to_munch(), **attrs)
 
         try:
             patch = jsonpatch.JsonPatch.from_diff(
-                machine._to_munch(),
-                new_config)
+                machine._to_munch(), new_config
+            )
         except Exception as e:
             raise exc.OpenStackCloudException(
                 "Machine update failed - Error generating JSON patch object "
                 "for submission to the API. Machine: %s Error: %s"
-                % (name_or_id, e))
+                % (name_or_id, e)
+            )
 
         if not patch:
-            return dict(
-                node=machine,
-                changes=None
-            )
+            return dict(node=machine, changes=None)
 
         change_list = [change['path'] for change in patch]
         node = self.baremetal.update_node(machine, **attrs)
-        return dict(
-            node=node,
-            changes=change_list
-        )
+        return dict(node=node, changes=change_list)
 
     def attach_port_to_machine(self, name_or_id, port_name_or_id):
         """Attach a virtual port to the bare metal machine.
@@ -434,7 +457,8 @@ class BaremetalCloudMixin:
         """List virtual ports attached to the bare metal machine.
 
         :param string name_or_id: A machine name or UUID.
-        :returns: List of ``munch.Munch`` representing the ports.
+        :returns: List of ``openstack.Resource`` objects representing
+            the ports.
         """
         machine = self.get_machine(name_or_id)
         vif_ids = self.baremetal.list_node_vifs(machine)
@@ -456,16 +480,15 @@ class BaremetalCloudMixin:
         self.baremetal.validate_node(name_or_id, required=ifaces)
 
     def validate_node(self, uuid):
-        warnings.warn('validate_node is deprecated, please use '
-                      'validate_machine instead', DeprecationWarning)
+        warnings.warn(
+            'validate_node is deprecated, please use validate_machine instead',
+            os_warnings.OpenStackDeprecationWarning,
+        )
         self.baremetal.validate_node(uuid)
 
-    def node_set_provision_state(self,
-                                 name_or_id,
-                                 state,
-                                 configdrive=None,
-                                 wait=False,
-                                 timeout=3600):
+    def node_set_provision_state(
+        self, name_or_id, state, configdrive=None, wait=False, timeout=3600
+    ):
         """Set Node Provision State
 
         Enables a user to provision a Machine and optionally define a
@@ -492,15 +515,17 @@ class BaremetalCloudMixin:
         :rtype: :class:`~openstack.baremetal.v1.node.Node`.
         """
         node = self.baremetal.set_node_provision_state(
-            name_or_id, target=state, config_drive=configdrive,
-            wait=wait, timeout=timeout)
+            name_or_id,
+            target=state,
+            config_drive=configdrive,
+            wait=wait,
+            timeout=timeout,
+        )
         return node
 
     def set_machine_maintenance_state(
-            self,
-            name_or_id,
-            state=True,
-            reason=None):
+        self, name_or_id, state=True, reason=None
+    ):
         """Set Baremetal Machine Maintenance State
 
         Sets Baremetal maintenance state and maintenance reason.
@@ -584,28 +609,33 @@ class BaremetalCloudMixin:
         """
         self.baremetal.set_node_power_state(name_or_id, 'rebooting')
 
-    def activate_node(self, uuid, configdrive=None,
-                      wait=False, timeout=1200):
+    def activate_node(self, uuid, configdrive=None, wait=False, timeout=1200):
         self.node_set_provision_state(
-            uuid, 'active', configdrive, wait=wait, timeout=timeout)
+            uuid, 'active', configdrive, wait=wait, timeout=timeout
+        )
 
-    def deactivate_node(self, uuid, wait=False,
-                        timeout=1200):
+    def deactivate_node(self, uuid, wait=False, timeout=1200):
         self.node_set_provision_state(
-            uuid, 'deleted', wait=wait, timeout=timeout)
+            uuid, 'deleted', wait=wait, timeout=timeout
+        )
 
     def set_node_instance_info(self, uuid, patch):
-        warnings.warn("The set_node_instance_info call is deprecated, "
-                      "use patch_machine or update_machine instead",
-                      DeprecationWarning)
+        warnings.warn(
+            "The set_node_instance_info call is deprecated, "
+            "use patch_machine or update_machine instead",
+            os_warnings.OpenStackDeprecationWarning,
+        )
         return self.patch_machine(uuid, patch)
 
     def purge_node_instance_info(self, uuid):
-        warnings.warn("The purge_node_instance_info call is deprecated, "
-                      "use patch_machine or update_machine instead",
-                      DeprecationWarning)
-        return self.patch_machine(uuid,
-                                  dict(path='/instance_info', op='remove'))
+        warnings.warn(
+            "The purge_node_instance_info call is deprecated, "
+            "use patch_machine or update_machine instead",
+            os_warnings.OpenStackDeprecationWarning,
+        )
+        return self.patch_machine(
+            uuid, dict(path='/instance_info', op='remove')
+        )
 
     def wait_for_baremetal_node_lock(self, node, timeout=30):
         """Wait for a baremetal node to have no lock.
@@ -615,7 +645,10 @@ class BaremetalCloudMixin:
         :raises: OpenStackCloudException upon client failure.
         :returns: None
         """
-        warnings.warn("The wait_for_baremetal_node_lock call is deprecated "
-                      "in favor of wait_for_node_reservation on the baremetal "
-                      "proxy", DeprecationWarning)
+        warnings.warn(
+            "The wait_for_baremetal_node_lock call is deprecated "
+            "in favor of wait_for_node_reservation on the baremetal "
+            "proxy",
+            os_warnings.OpenStackDeprecationWarning,
+        )
         self.baremetal.wait_for_node_reservation(node, timeout)
